project_name: "{{ project_name }}"
author: "{{ author_name }}"
description: "{{ description }}"
version: "{{ version }}"

# Data Sources (URLs or Kaggle Handles)
data_urls:
  iris: "https://raw.githubusercontent.com/mwaskom/seaborn-data/master/iris.csv"
  titanic: "https://raw.githubusercontent.com/datasciencedojo/datasets/master/titanic.csv"

datasets:
  # Notebook Name: Kaggle Dataset Handle
  Base_Kaggle: "titanic"
  # Usage: kh.dataset_download(SETTINGS['datasets']['titanic'])
  titanic: "heptapod/titanic"
